@@ -4,7 +4,12 @@ import logging
 import click
 from flask.cli import with_appcontext
 
-from scout.load.report import load_delivery_report, load_cnv_report, load_coverage_qc_report
+from scout.load.report import (
+    load_cnv_report,
+    load_coverage_qc_report,
+    load_delivery_report,
+    load_gene_fusion_report,
+)
 from scout.server.extensions import store
 
 LOG = logging.getLogger(__name__)
@@ -77,3 +82,28 @@ def coverage_qc_report(case_id, report_path, update):
     except Exception as err:
         LOG.error(err)
         raise click.Abort()
+
+
+@click.command("gene-fusion-report")
+@click.argument("case-id", required=True)
+@click.argument("report-path", type=click.Path(exists=True), required=True)
+@click.option("-r", "--research", is_flag=True, help="Update research gene fusion report")
+@click.option("-u", "--update", is_flag=True, help="Update a gene fusion report for a case")
+@with_appcontext
+def gene_fusion_report(case_id, report_path, research, update):
+    """Add or update a gene fusion report (clinical or research) for a case."""
+
+    adapter = store
+
+    try:
+        load_gene_fusion_report(
+            adapter=adapter,
+            case_id=case_id,
+            report_path=report_path,
+            research=research,
+            update=update,
+        )
+        LOG.info("saved report to case!")
+    except Exception as err:
+        LOG.error(err)
+        raise click.Abort()
