@@ -1,26 +1,22 @@
+import logging
 from datetime import datetime
 from pprint import pprint as pp
 
 import pytest
+from pydantic import ValidationError
 
 from scout.constants import REV_SEX_MAP
 from scout.exceptions import ConfigError, PedigreeError
-from scout.parse.case import (
-    parse_case,
-    parse_case_data,
-    parse_custom_images,
-    parse_individual,
-    parse_individuals,
-    parse_ped,
-    removeNoneValues,
-)
+from scout.parse.case import parse_case_config, parse_case_data, parse_ped, remove_none_values
+
+LOG = logging.getLogger(__name__)
 
 
 def test_parse_case_no_date(scout_config):
     # GIVEN a load config without a date
     scout_config.pop("analysis_date")
     # WHEN case is parsed
-    case_data = parse_case(scout_config)
+    case_data = parse_case_config(scout_config)
     # THEN the todays date should have been set
     assert "analysis_date" not in scout_config
     assert isinstance(case_data["analysis_date"], datetime)
@@ -30,7 +26,7 @@ def test_parse_case_wrong_date_string(scout_config):
     # GIVEN you load info thats not a date
     scout_config["analysis_date"] = "not a date"
     # WHEN case is parsed
-    case_data = parse_case(scout_config)
+    case_data = parse_case_config(scout_config)
     # THEN the todays date should have been set
     assert isinstance(scout_config["analysis_date"], str)
     assert isinstance(case_data["analysis_date"], datetime)
@@ -40,7 +36,7 @@ def test_parse_case_date_string(scout_config):
     # GIVEN a load config with date string
     # WHEN case is parsed
     scout_config["analysis_date"] = "2019-11-05"
-    case_data = parse_case(scout_config)
+    case_data = parse_case_config(scout_config)
     # THEN the case should have a datetime object
     assert isinstance(scout_config["analysis_date"], str)
     assert isinstance(case_data["analysis_date"], datetime)
@@ -49,7 +45,7 @@ def test_parse_case_date_string(scout_config):
 def test_parse_case_date(scout_config):
     # GIVEN you load sample information from a scout config
     # WHEN case is parsed
-    case_data = parse_case(scout_config)
+    case_data = parse_case_config(scout_config)
     # THEN the case should have an analysis_date
     assert isinstance(scout_config["analysis_date"], datetime)
     assert isinstance(case_data["analysis_date"], datetime)
@@ -65,9 +61,7 @@ def test_parse_case_date(scout_config):
         "gene_fusion_report",
         "lims_id",
         "owner",
-        "peddy_check",
         "peddy_ped",
-        "peddy_sex",
         "phenotype_terms",
         "rank_model_version",
         "rank_score_threshold",
@@ -78,20 +72,27 @@ def test_parse_case_date(scout_config):
 def test_parse_case_parsing(scout_config, param_name):
     # GIVEN you load sample information from a scout config
     # WHEN case is parsed
-    case_data = parse_case(scout_config)
+    case_data = parse_case_config(scout_config)
     # THEN the case should have a the parameter
     assert case_data[param_name] == scout_config[param_name]
 
 
 @pytest.mark.parametrize(
     ("param_name", "alias_name"),
-    ([("case_id", "family"), ("default_panels", "default_gene_panels")]),
+    (
+        [
+            ("case_id", "family"),
+            ("default_panels", "default_gene_panels"),
+            ("peddy_ped_check", "peddy_check"),
+            ("peddy_sex_check", "peddy_sex"),
+        ]
+    ),
 )
 def test_parse_case_aliases(scout_config, param_name, alias_name):
     """Certain configuration parameters have an alias externally"""
     # GIVEN you load sample information from a scout config
     # WHEN case is parsed
-    case_data = parse_case(scout_config)
+    case_data = parse_case_config(scout_config)
     # THEN the case a correct case id
     assert case_data[param_name] == scout_config[alias_name]
 
@@ -99,61 +100,70 @@ def test_parse_case_aliases(scout_config, param_name, alias_name):
 def test_parse_case_madeline(scout_config):
     # GIVEN you load sample information from a scout config
     # WHEN case is parsed
-    case_data = parse_case(scout_config)
+    case_data = parse_case_config(scout_config)
     # THEN the case a correct case id
     assert case_data["madeline_info"]
 
 
-def test_parse_case_custom_images(scout_config):
+def test_parse_custom_images(scout_config):
     """Test parsing of case"""
-    # Given you load custom images info from scout config
-    custom_images = parse_custom_images(scout_config)
+    # GIVEN you load custom images info from scout config
+
+    case_data = parse_case_config(scout_config)
+    original_custom_images = scout_config["custom_images"]
     # WHEN images is parsed
+    parsed_custom_images = case_data["custom_images"]
+
     # THEN custom_images should have the same sections
-    cnf_img = scout_config["custom_images"]
-    assert cnf_img.keys() == custom_images.keys()
-    # THEN custom_images should have the same number of images
+    assert original_custom_images.keys() == parsed_custom_images.keys()
+
     assert all(
-        len(custom_images["case"][section]) == len(cnf_img["case"][section])
-        for section in custom_images["case"]
+        len(parsed_custom_images["case"][section]) == len(original_custom_images["case"][section])
+        for section in parsed_custom_images["case"]
     )
-    # Given that some custom images are of not supported formats
-    custom_images = parse_custom_images(
-        {
-            "custom_images": {
-                "case": {
-                    "section_one": [
-                        {
-                            "title": "A png image",
-                            "description": "desc",
-                            "path": "scout/demo/images/custom_images/640x480_one.png",
-                        },
-                        {
-                            "title": "A bitmap image",
-                            "description": "desc",
-                            "path": "scout/demo/images/custom_images/640x480_one.bnp",
-                        },
-                    ],
-                    "section_two": [
-                        {
-                            "title": "A pdf image",
-                            "description": "desc",
-                            "path": "scout/demo/images/custom_images/640x480_one.pdf",
-                        },
-                    ],
-                }
-            }
+
+
+def test_parse_incorrect_custom_images(scout_config):
+    """Test parsing of case with a mix of accepted file types and not-accepted
+    file types"""
+
+    # GIVEN one valid suffix and two invalid suffixes (.bnp, .pdf)
+    scout_config["custom_images"] = {
+        "case": {
+            "section_one": [
+                {
+                    "title": "A png image",
+                    "description": "desc",
+                    "path": "scout/demo/images/custom_images/640x480_one.png",
+                },
+                {
+                    "title": "An incorrect bitmap image",
+                    "description": "desc",
+                    "path": "scout/demo/images/custom_images/640x480_one.bnp",
+                },
+            ],
+            "section_two": [
+                {
+                    "title": "A pdf image, not allowed",
+                    "description": "desc",
+                    "path": "scout/demo/images/custom_images/640x480_one.pdf",
+                },
+            ],
         }
-    )
+    }
+
+    # WHEN images is parsed
+    parsed_data = parse_case_config(scout_config)
+
     # THEN check that non valid image formats are being rejected
-    assert len(custom_images["case"]["section_one"]) == 1
-    assert "section_two" not in custom_images
+    assert len(parsed_data["custom_images"]["case"]["section_one"]) == 1
+    assert "section_two" not in parsed_data["custom_images"]
 
 
 def test_parse_case_collaborators(scout_config):
     # GIVEN you load sample information from a scout config
     # WHEN case is parsed
-    case_data = parse_case(scout_config)
+    case_data = parse_case_config(scout_config)
     # THEN the case should have a list with collaborators
     assert case_data["collaborators"] == [scout_config["owner"]]
 
@@ -164,7 +174,7 @@ def test_parse_case_collaborators(scout_config):
 def test_parse_case_vcf_files(scout_config, vcf_file):
     # GIVEN you load sample information from a scout config
     # WHEN case is parsed
-    case_data = parse_case(scout_config)
+    case_data = parse_case_config(scout_config)
     # THEN the case should the same vcf files as specified in the
     assert case_data["vcf_files"][vcf_file] == scout_config[vcf_file]
 
@@ -176,7 +186,7 @@ def test_parse_case_bams(scout_config, bam_name):
     for sample in scout_config["samples"]:
         sample[bam_name] = bam_path
     # WHEN case is parsed
-    case_data = parse_case(scout_config)
+    case_data = parse_case_config(scout_config)
 
     # THEN assert that bam files are added correct
     for ind in case_data["individuals"]:
@@ -194,7 +204,7 @@ def test_parse_case_multiple_alignment_files(scout_config):
         sample["alignment_path"] = cram_path
 
     # WHEN case is parsed
-    case_data = parse_case(scout_config)
+    case_data = parse_case_config(scout_config)
 
     # THEN assert that cram files are added correctly, ignoring bam
     for ind in case_data["individuals"]:
@@ -229,7 +239,7 @@ def test_parse_case_ped_file(ped_file):
 def test_parse_case_minimal_config(minimal_config):
     # GIVEN a minimal config
     # WHEN parsing the config
-    case_data = parse_case(minimal_config)
+    case_data = parse_case_config(minimal_config)
     # THEN assert is was parsed correct
     assert case_data
 
@@ -269,64 +279,49 @@ def test_parse_case_two_cases_ped():
         parse_ped(case_lines)
 
 
-def test_no_individuals():
+def test_no_individuals(scout_config):
     # GIVEN a list with no indioviduals
-    samples = []
+    scout_config["samples"] = []
     # WHEN parsing the individuals
     with pytest.raises(PedigreeError):
         # THEN error should be raised since a family has to have individuals
-        parse_individuals(samples)
+        parse_case_config(scout_config)
 
 
-def test_parse_missing_id():
-    # GIVEN a individual without sample_id
-    sample_info = {"sex": "male", "phenotype": "affected"}
+@pytest.mark.parametrize("param", ["sample_id", "sex", "phenotype"])
+def test_mandatory_param_missing(scout_config, param):
+    individual = {"sample_id": "1", "sex": "male", "phenotype": "affected"}
+    # GIVEN a individual with missing mandatory param
+    del individual[param]
+    scout_config["samples"] = [individual]
     # WHEN a individual is parsed
-    with pytest.raises(PedigreeError):
-        # THEN a PedigreeError should be raised
-        parse_individual(sample_info)
+    with pytest.raises(ValidationError):
+        # THEN a ValidationError should be raised
+        parse_case_config(scout_config)
 
 
-def test_parse_missing_sex():
-    # GIVEN a individual without sex
-    sample_info = {"sample_id": "1", "phenotype": "affected"}
-    # WHEN a individual is parsed
-    with pytest.raises(PedigreeError):
-        # THEN a PedigreeError should be raised
-        parse_individual(sample_info)
-
-
-def test_parse_missing_phenotype():
-    # GIVEN a individual without phenotype
-    sample_info = {"sample_id": "1", "sex": "male"}
-    # WHEN a individual is parsed
-    with pytest.raises(PedigreeError):
-        # THEN a PedigreeError should be raised
-        parse_individual(sample_info)
-
-
-def test_parse_wrong_phenotype():
+def test_parse_wrong_phenotype(scout_config):
     # GIVEN a individual with wrong phenotype format
-    sample_info = {"sample_id": "1", "sex": "male", "phenotype": "not-affected"}
+    scout_config["samples"] = [{"sample_id": "1", "sex": "male", "phenotype": "not-affected"}]
     # WHEN a individual is parsed
-    with pytest.raises(PedigreeError):
+    with pytest.raises(ValidationError):
         # THEN a PedigreeError should be raised
-        parse_individual(sample_info)
+        parse_case_config(scout_config)
 
 
-def test_parse_wrong_sex():
+def test_parse_wrong_sex(scout_config):
     # GIVEN a individual with wrong sex format
-    sample_info = {"sample_id": "1", "sex": "flale", "phenotype": "affected"}
+    scout_config["samples"] = [{"sample_id": "1", "sex": "flale", "phenotype": "affected"}]
     # WHEN a individual is parsed
-    with pytest.raises(PedigreeError):
+    with pytest.raises(ValidationError):
         # THEN a PedigreeError should be raised
-        parse_individual(sample_info)
+        parse_case_config(scout_config)
 
 
 def test_wrong_relations(scout_config):
     # GIVEN a individual with correct family info
     # Nothing should happend here
-    assert parse_case(scout_config)
+    assert parse_case_config(scout_config)
 
     # WHEN changing mother id in proband to non-existing id
     samples_list = scout_config["samples"]
@@ -341,24 +336,24 @@ def test_wrong_relations(scout_config):
 
     # THEN a PedigreeError should be raised
     with pytest.raises(PedigreeError):
-        parse_case(scout_config)
+        parse_case_config(scout_config)
 
 
-def test_removeNoneValues():
+def test_remove_none_values():
     # WHEN a dict *not* containing a None value
     d = {"a": "1", "b": 2, "c": 3}
 
     # THEN calling removeNoneValues(dict) will not change dict
-    assert d == removeNoneValues(d)
+    assert d == remove_none_values(d)
 
 
-def test_removeNoneValues():
+def test_remove_none_values():
     # WHEN a dict containing a value which is None
     d = {"a": "1", "b": 2, "c": None}
 
     # THEN calling removeNoneValues(dict) will remove key-value pair
     # where value=None
-    assert {"a": "1", "b": 2} == removeNoneValues(d)
+    assert {"a": "1", "b": 2} == remove_none_values(d)
 
 
 def test_parse_optional_igv_param(scout_config):
@@ -373,11 +368,10 @@ def test_parse_optional_igv_param(scout_config):
         sample["upd_regions_bed"] = "path/to/up"
         sample["upd_sites_bed"] = "path/to/us"
         sample["tiddit_coverage_wig"] = "path/to/tc"
-        sample["chromograph_images"] = "path/to/ci"
     scout_config["samples"] = samples
 
     # THEN parsing the config will add those to case data
-    case_data = parse_case(scout_config)
+    case_data = parse_case_config(scout_config)
     case_list = []
     config_list = []
     for individual in case_data["individuals"]:
@@ -388,7 +382,6 @@ def test_parse_optional_igv_param(scout_config):
                 individual["upd_regions_bed"],
                 individual["upd_sites_bed"],
                 individual["tiddit_coverage_wig"],
-                individual["chromograph_images"],
             )
         )
 
@@ -400,7 +393,6 @@ def test_parse_optional_igv_param(scout_config):
                 sample["upd_regions_bed"],
                 sample["upd_sites_bed"],
                 sample["tiddit_coverage_wig"],
-                sample["chromograph_images"],
             )
         )
 
@@ -417,7 +409,7 @@ def test_missing_optional_igv_param(scout_config):
     scout_config.pop("tiddit_coverage_wig", "ignore_return")
 
     # THEN parsing the config will not raise an exception
-    case_data = parse_case(scout_config)
+    case_data = parse_case_config(scout_config)
     assert case_data
 
 
@@ -427,6 +419,6 @@ def test_missing_mandatory_config_key(scout_config, key):
 
     ## WHEN deleting key
     scout_config.pop(key)
-    ## THEN calling parse_case() will raise ConfigError
+    ## THEN calling parse_case_config() will raise ConfigError
     with pytest.raises(ConfigError):
-        parse_case(scout_config)
+        parse_case_config(scout_config)
