@@ -954,122 +954,45 @@ def test_omimterms(app, test_omim_term):
         assert resp.mimetype == "application/json"
 
 
-def _test_beacon_submit(client, institute_obj, case_obj, vcf_files, mocker, mock_redirect):
-    """Test beacon connection: given client, produce response"""
+def test_beacon_add_variants(app, institute_obj, case_obj, mocker, mock_redirect):
+    """Test Beacon add variants endpoint"""
 
     mocker.patch("scout.server.blueprints.cases.views.redirect", return_value=mock_redirect)
 
-    form_data = {
-        "case": case_obj["_id"],
-        "samples": "affected",
-        "vcf_files": vcf_files,
-    }
-    # WHEN case page is loaded
-    resp = client.post(url_for("cases.beacon_submit"), data=form_data)
-    return resp
-
-
-def test_beacon_submit_wrong_config(app, institute_obj, case_obj, mocker, mock_redirect):
-    """Test saving variants to a Beacon server when Beacon connection parameters are not set"""
-
-    # GIVEN an initialized app
+    # GIVEN an app with an authenticated user
     with app.test_client() as client:
-        # GIVEN that the user could be logged in
-        resp = client.get(url_for("auto_login"))
-        assert resp.status_code == 200
+        client.get(url_for("auto_login"))
 
-        vcf_files = ["vcf_snv_research", "vcf_snv"]
-        # WHEN case page is loaded without beacon config settings
-        resp = _test_beacon_submit(
-            client, institute_obj, case_obj, vcf_files, mocker, mock_redirect
+        # THE beacon_add_variants endpoint should work and return page redirect
+        data = {}
+        resp = client.post(
+            url_for(
+                "cases.beacon_add_variants",
+                institute_id=institute_obj["internal_id"],
+                case_name=case_obj["display_name"],
+            ),
+            data=data,
         )
-
-        # THEN it should redirect to case page
         assert resp.status_code == 302
-        updated_case = store.case_collection.find_one()
-        # but submission should not be saved in case object
-        assert "beacon" not in updated_case
 
 
-def test_beacon_submit(
-    app, institute_obj, case_obj, monkeypatch, mocked_beacon, mocker, mock_redirect
-):
-    """Test submitting variants to a Beacon server"""
-
-    # GIVEN a mocked Beacon server
-    def mock_response(*args, **kwargs):
-        return mocked_beacon
-
-    monkeypatch.setattr(requests, "post", mock_response)
-
-    # GIVEN an initialized app containing the right config settings
-    current_app.config["BEACON_URL"] = mocked_beacon.url
-    current_app.config["BEACON_TOKEN"] = mocked_beacon.token
-
-    with app.test_client() as client:
-        # GIVEN that the user could be logged in
-        resp = client.get(url_for("auto_login"))
-        assert resp.status_code == 200
-
-        vcf_files = ["vcf_snv_research", "vcf_snv"]
-        # WHEN case page is loaded
-        resp = _test_beacon_submit(
-            client,
-            institute_obj,
-            case_obj,
-            vcf_files,
-            mocker,
-            mock_redirect,
-        )
-
-        # THEN it should redirect to case page
-        assert resp.status_code == 302
-        updated_case = store.case_collection.find_one()
-        # and submissions details should be saved in case object
-        assert "beacon" in updated_case
-        assert updated_case["beacon"]["samples"]
-        assert updated_case["beacon"]["vcf_files"] == vcf_files
-
-
-def test_beacon_remove(
-    app, institute_obj, case_obj, monkeypatch, mocked_beacon, mocker, mock_redirect
-):
-    """Test removing variants submitted to Beacon for test case"""
+def test_beacon_remove_variants(app, institute_obj, case_obj, mocker, mock_redirect):
+    """Test Beacon remove variants endpoint"""
 
     mocker.patch("scout.server.blueprints.cases.views.redirect", return_value=mock_redirect)
 
-    # GIVEN a mocked Beacon server
-    def mock_response(*args, **kwargs):
-        return mocked_beacon
-
-    monkeypatch.setattr(requests, "delete", mock_response)
-
-    # GIVEN a case with variants saved to Beacon
-    store.case_collection.find_one_and_update(
-        {"_id": case_obj["_id"]}, {"$set": {"beacon": {"samples": ["ADM1059A2"]}}}
-    )
-    case_obj = store.case_collection.find_one()
-    assert case_obj["beacon"]
-
-    # GIVEN an initialized app containing the right config settings
-    current_app.config["BEACON_URL"] = mocked_beacon.url
-    current_app.config["BEACON_TOKEN"] = mocked_beacon.token
-
+    # GIVEN an app with an authenticated user
     with app.test_client() as client:
-        # GIVEN that the user could be logged in
-        resp = client.get(url_for("auto_login"))
-        assert resp.status_code == 200
+        client.get(url_for("auto_login"))
 
-        # WHEN users submits a GET request to remove data from Beacon
+        # THE beacon_add_variants endpoint should work and return page redirect
+        data = {}
         resp = client.get(
             url_for(
-                "cases.beacon_remove",
-                case_id=case_obj["_id"],
-            )
+                "cases.beacon_remove_variants",
+                institute_id=institute_obj["internal_id"],
+                case_name=case_obj["display_name"],
+            ),
+            data=data,
         )
-        # THEN it should redirect to case page
         assert resp.status_code == 302
-
-        # And case should no more have an associated Beacon submission
-        updated_case = store.case_collection.find_one()
-        assert "beacon" not in updated_case
