@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 import datetime
 
-import pytest
 from flask import url_for
 from flask_login import current_user
 
@@ -15,6 +14,30 @@ TEST_SUBPANEL = dict(
 )
 
 
+def test_events_timeline(app, user_obj, institute_obj, case_obj):
+    """Test the wiew that returns the last 100 groups of events for a user"""
+
+    # GIVEN an initialized app
+    with app.test_client() as client:
+        # GIVEN that the user could be logged in
+        client.get(url_for("auto_login"))
+
+        # GIVEN one user event present in the database
+        store.assign(institute=institute_obj, case=case_obj, user=user_obj, link="test_link")
+        assert store.event_collection.find_one()
+
+        resp = client.get(
+            url_for(
+                "overview.timeline",
+            )
+        )
+        # THEN the page should not return error
+        assert resp.status_code == 200
+
+        # AND the event should be displayed on the timeline page
+        assert "assigned" in str(resp.data)
+
+
 def test_advanced_phenotypes_POST(app, user_obj, institute_obj):
     """Test the view showing the available phenotype models for an institute, after sending POST request with new phenotype model data"""
 
