@@ -139,6 +139,11 @@ def test_add_variants(app, user_obj, case_obj):
         updated_case = store.case_collection.find_one()
         assert "beacon" in updated_case
 
+        # AND the relative event should be saved in the database:
+        beacon_event = store.event_collection.find_one()
+        assert beacon_event["verb"] == "beacon_add"
+        assert beacon_event["link"] == f"/{case_obj['owner']}/{case_obj['display_name']}"
+
 
 @responses.activate
 def test_remove_variants(app, user_obj, institute_obj, case_obj):
@@ -168,3 +173,8 @@ def test_remove_variants(app, user_obj, institute_obj, case_obj):
         # THEN Beacon data should be removed from case document
         updated_case = store.case_collection.find_one()
         assert "beacon" not in updated_case
+
+        # AND the relative event should be saved in the database:
+        beacon_event = store.event_collection.find_one()
+        assert beacon_event["verb"] == "beacon_remove"
+        assert beacon_event["link"] == f"/{case_obj['owner']}/{case_obj['display_name']}"
